==> haskell-wai-handler-launch-3.0.2.2-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.2
id: wai-handler-launch-3.0.2.2-3TLoZqAxqvfKeMlRhka7ns
key: wai-handler-launch-3.0.2.2-3TLoZqAxqvfKeMlRhka7ns
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
abi: db22ed16eb29942a0c69c9f5f2230e17
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wai-handler-launch-3.0.2.2
hs-libraries: HSwai-handler-launch-3.0.2.2-3TLoZqAxqvfKeMlRhka7ns
depends:
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ process-1.4.3.0
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.2-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.2
id: wai-handler-launch-3.0.2.2-1yA2JUA2cvO3M08QwDp5Jb
key: wai-handler-launch-3.0.2.2-1yA2JUA2cvO3M08QwDp5Jb
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
abi: 79b163ae5af23572fcbbbd5c00345b4f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wai-handler-launch-3.0.2.2
hs-libraries: HSwai-handler-launch-3.0.2.2-1yA2JUA2cvO3M08QwDp5Jb
depends:
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ process-1.4.3.0
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    warp-3.2.13-2zIfvy7PaU822kbwwTyJQq
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
